unit Body;

interface

uses Classes, PlugAPI;

function Setup( const GroupName: PChar ): Boolean; stdcall;
procedure Open( const GroupName: PChar; const PlugDir: PChar; const DecodeDir: PChar ); stdcall;
procedure Item( const Article: TArticleData; var MarkSubject: Boolean; var MarkFileName: Boolean ); stdcall;
procedure Close( const GroupName: PChar ); stdcall;
procedure FileDelete( const GroupName: PChar; const Dir: PChar; const Name: PChar ); stdcall;
procedure FeedArticle( const Article: TArticleData; var MarkSubject: Boolean;
					   var MarkFileName: Boolean; Shift: TShiftState ); stdcall;
procedure StartUp( const PlugDir: PChar ); stdcall;
procedure ShutDown; stdcall;

implementation

uses Controls, SetupFrm;

//
// This function handles the "Setup" of the plugin. This gets
// called from BNR when the user presses the "Setup..." button on
// the plugin tabsheet.
//
// Parameters
//	GroupName	Name of the newsgroup that uses this plugin
//
// Return value
//	Boolean		True if the setup was succesfull, False otherwise
//
function Setup( const GroupName: PChar ): Boolean; stdcall;
begin
	Result := True;
	SetupForm := TSetupForm.Create( nil );
	SetupForm.NewsGroup.Caption := String(GroupName);
	if SetupForm.ShowModal = mrOK then
	begin
		// User pressed OK on the setup form.
		// NOTE! The form has already been freed from memory at this stage!
	end;
	SetupForm := nil;
end;

procedure Open( const GroupName: PChar; const PlugDir: PChar; const DecodeDir: PChar ); stdcall;
begin
	// Add code to be performed immediately before going thru
	// all the articles of the given newsgroups.
end;

procedure Close( const GroupName: PChar ); stdcall;
begin
	// Add code to be performed immediately after going thru
	// all the articles of the given newsgroups.
end;

procedure Item( const Article: TArticleData; var MarkSubject: Boolean; var MarkFileName: Boolean ); stdcall;
begin
	// Add code to handle each article here.
	// DO NOT CHANGE ANY OF THE INPUT PChar DATA!

	// Return True in MarkSubject if the subject column should be
	// marked with the plugin special color.

	// Return True in MarkFileName if the filename column should be
	// marked with the plugin special color.

	if Article.FBytes > 100000 then
		MarkSubject := True;
	if Article.FBytes > 200000 then
		MarkFileName := True;
end;

procedure FileDelete( const GroupName: PChar; const Dir: PChar; const Name: PChar ); stdcall;
begin
	// This routine gets called when the user deletes a file.
end;

procedure FeedArticle( const Article: TArticleData; var MarkSubject: Boolean;
					   var MarkFileName: Boolean; Shift: TShiftState  ); stdcall;
begin
	// Add code to handle user article feed here.
	// DO NOT CHANGE ANY OF THE INPUT PChar DATA!

	// Return True in MarkSubject if the subject column should be
	// marked with the plugin special color.

	if not (ssShift in Shift) then
		MarkSubject := True;

	// Return True in MarkFileName if the filename column should be
	// marked with the plugin special color.

	if not (ssCtrl in Shift) then
		MarkFileName := True;

end;

procedure StartUp( const PlugDir: PChar ); stdcall;
begin
	// This function gets called when this plugin has just been
	// loaded into memory. PlugDir is the directory where this
	// plugin was loaded from.

end;

procedure ShutDown; stdcall;
begin
	// This function gets called when this plugin is about to be
	// freed from memory.

end;

end.
